import { NextQueryParams, NextQueryParamsAdapter } from '../types';
import { UseNextQueryParamsReturn } from '../types/UseNextQueryParams';
/**
 * The `useNextQueryParams` hook registers query param states and updates the URL query params when the states change.
 *
 * @param params - The query param states to register. {@link NextQueryParams}
 * @param adapter - The router adapter to use for interacting with the URL query params {@link NextQueryParamsAdapter}. If not provided, the adapter from the nearest provider {@link NextQueryParamsProvider} will be used.
 *
 * @example
 * ```tsx
 * function MyComponent() {
 *   const [str, setStr] = useState('world');
 *
 *   useNextQueryParams({
 *    hello: createStrQueryParam({
 *      value: str,
 *      onChange: setStr,
 *    })
 *   });
 *
 *   return <div>Hello {str}</div>;
 * }
 * ```
 */
export declare function useNextQueryParams<T extends Record<string, unknown> = Record<string, any>>(params: NextQueryParams<T>, adapter?: Partial<NextQueryParamsAdapter>): UseNextQueryParamsReturn;
//# sourceMappingURL=useNextQueryParams.d.ts.map