/**
 * Builds a query param for a number array value.
 *
 * @param props - The props for the query param function {@link CreateQueryParamProps}
 *
 * @returns A query param to be used in the `useQueryParams` hook {@link NextQueryParam}
 *
 * @example
 * ```tsx
 * function MyComponent() {
 *   const [numArr, setNumArr] = useState([1, 2, 3]);
 *   useNextQueryParams({
 *     numArr: createNumArrQueryParam({
 *       value: numArr,
 *       onChange: setNumArr,
 *     }),
 *   });
 *   return <div>Hello {numArr.join(', ')}</div>;
 *   // ?numArr=1&numArr=2&numArr=3
 * }
 */
export declare const createNumArrQueryParam: import("../../../types/CreateQueryParam").CreateQueryParam<number[], object>;
//# sourceMappingURL=createNumArrQueryParam.d.ts.map